summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/indi/indiapi.h
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/indi/indiapi.h')
-rw-r--r--kstars/kstars/indi/indiapi.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kstars/kstars/indi/indiapi.h b/kstars/kstars/indi/indiapi.h
index 324b7824..d2ffd6fe 100644
--- a/kstars/kstars/indi/indiapi.h
+++ b/kstars/kstars/indi/indiapi.h
@@ -136,7 +136,7 @@ typedef struct {
char label[MAXINDILABEL];
/** malloced text string */
char *text;
/** pointer to parent */
struct _ITextVectorProperty *tvp;
/** handy place to hang helper info */
void *aux0;
@@ -182,7 +182,7 @@ typedef struct {
double min, max; /** range, ignore if min == max */
double step; /** step size, ignore if step == 0 */
double value; /** current value */
- struct _INumberVectorProperty *nvp; /** pointer to parent */
+ struct _INumberVectorProperty *nvp; /** pointer to tqparent */
void *aux0, *aux1; /** handy place to hang helper info */
} INumber;
@@ -235,7 +235,7 @@ typedef struct {
char name[MAXINDINAME]; /** index name */
char label[MAXINDILABEL]; /** this switch's label */
ISState s; /** this switch's state */
- struct _ISwitchVectorProperty *svp; /** pointer to parent */
+ struct _ISwitchVectorProperty *svp; /** pointer to tqparent */
void *aux; /** handy place to hang helper info */
} ISwitch;
@@ -276,7 +276,7 @@ typedef struct {
char name[MAXINDINAME]; /** index name */
char label[MAXINDILABEL]; /** this lights's label */
IPState s; /** this lights's state */
- struct _ILightVectorProperty *lvp; /** pointer to parent */
+ struct _ILightVectorProperty *lvp; /** pointer to tqparent */
void *aux; /** handy place to hang helper info */
} ILight;
@@ -320,7 +320,7 @@ typedef struct { /* one BLOB descriptor */
int bloblen;
/** n uncompressed bytes */
int size;
/** pointer to parent */
struct _IBLOBVectorProperty *bvp;
/** handy place to hang helper info */
void *aux0, *aux1, *aux2;
@@ -136,7 +136,7 @@ typedef struct {
/** malloced text string */
char *text;
- /** pointer to parent */
+ /** pointer to tqparent */
struct _ITextVectorProperty *tvp;
/** handy place to hang helper info */
@@ -320,7 +320,7 @@ typedef struct { /* one BLOB descriptor */
/** n uncompressed bytes */
int size;
- /** pointer to parent */
+ /** pointer to tqparent */
struct _IBLOBVectorProperty *bvp;
/** handy place to hang helper info */